==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/gromacs/utility/inmemoryserializer.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2016,2017, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares gmx::ISerializer implementation for in-memory serialization.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_INMEMORYSERIALIZER_H
#define GMX_UTILITY_INMEMORYSERIALIZER_H

#include <vector>

#include "gromacs/utility/classhelpers.h"
#include "gromacs/utility/iserializer.h"

namespace gmx
{

class InMemorySerializer : public ISerializer
{
    public:
        InMemorySerializer();
        virtual ~InMemorySerializer();

        std::vector<char> finishAndGetBuffer();

        // From ISerializer
        virtual bool reading() const { return false; }
        virtual void doBool(bool *value);
        virtual void doUChar(unsigned char *value);
        virtual void doInt(int *value);
        virtual void doInt64(gmx_int64_t *value);
        virtual void doFloat(float *value);
        virtual void doDouble(double *value);
        virtual void doString(std::string *value);

    private:
        class Impl;

        PrivateImplPointer<Impl> impl_;
};

class InMemoryDeserializer : public ISerializer
{
    public:
        explicit InMemoryDeserializer(const std::vector<char> &buffer);
        virtual ~InMemoryDeserializer();

        // From ISerializer
        virtual bool reading() const { return true; }
        virtual void doBool(bool *value);
        virtual void doUChar(unsigned char *value);
        virtual void doInt(int *value);
        virtual void doInt64(gmx_int64_t *value);
        virtual void doFloat(float *value);
        virtual void doDouble(double *value);
        virtual void doString(std::string *value);

    private:
        class Impl;

        PrivateImplPointer<Impl> impl_;
};

} // namespace gmx

#endif

==> gromacs_2019.1.orig.tar.gz: gromacs-2019.1/src/gromacs/utility/inmemoryserializer.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2016,2017,2018, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares gmx::ISerializer implementation for in-memory serialization.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_INMEMORYSERIALIZER_H
#define GMX_UTILITY_INMEMORYSERIALIZER_H

#include <vector>

#include "gromacs/utility/classhelpers.h"
#include "gromacs/utility/iserializer.h"

namespace gmx
{

class InMemorySerializer : public ISerializer
{
    public:
        InMemorySerializer();
        ~InMemorySerializer() override;

        std::vector<char> finishAndGetBuffer();

        // From ISerializer
        bool reading() const override { return false; }
        void doBool(bool *value) override;
        void doUChar(unsigned char *value) override;
        void doInt(int *value) override;
        void doInt64(int64_t *value) override;
        void doFloat(float *value) override;
        void doDouble(double *value) override;
        void doString(std::string *value) override;

    private:
        class Impl;

        PrivateImplPointer<Impl> impl_;
};

class InMemoryDeserializer : public ISerializer
{
    public:
        explicit InMemoryDeserializer(const std::vector<char> &buffer);
        ~InMemoryDeserializer() override;

        // From ISerializer
        bool reading() const override { return true; }
        void doBool(bool *value) override;
        void doUChar(unsigned char *value) override;
        void doInt(int *value) override;
        void doInt64(int64_t *value) override;
        void doFloat(float *value) override;
        void doDouble(double *value) override;
        void doString(std::string *value) override;

    private:
        class Impl;

        PrivateImplPointer<Impl> impl_;
};

} // namespace gmx

#endif
